@@ -1,4 +1,5 @@
 import os
+import pprint
 import sys
 import traceback
 import asyncio
@@ -70,6 +71,8 @@ class KafkaLogger(metaclass=SingletonMeta):
             buffer_memory=67108864,  # 增大缓冲区内存
             connections_max_idle_ms=540000,  # 连接最大空闲时间
             reconnect_backoff_max_ms=10000,  # 增加重连退避最大时间
+            max_in_flight_requests_per_connection=1,  # 限制单个连接上未确认的请求数量
+            enable_idempotence=True,  # 开启幂等性
         )
 
         # 启动后台发送线程
@@ -487,22 +490,26 @@ class SYLogger:
             logger.info(_log)
 
         if os.getenv('DEV-LOG', 'false').lower() == 'true':
-            print(_log)
+            pprint(_log)
 
     @staticmethod
-    def info(msg: any):
+    def info(msg: any, *args, **kwargs):
         SYLogger._log(msg, "INFO")
 
     @staticmethod
-    def warning(msg: any):
+    def warning(msg: any, *args, **kwargs):
         SYLogger._log(msg, "WARNING")
 
     @staticmethod
-    def error(msg: any):
+    def debug(msg: any, *args, **kwargs):
+        SYLogger._log(msg, "DEBUG")
+
+    @staticmethod
+    def error(msg: any, *args, **kwargs):
         SYLogger._log(msg, "ERROR")
 
     @staticmethod
-    def exception(msg: any):
+    def exception(msg: any, *args, **kwargs):
         """记录异常信息，包括完整堆栈"""
         trace_id = SYLogger.get_trace_id()
 
